hive-ingest-kit.plaintext-parser

IWebsiteParser implementations for text/plain responses.

PlainTextParser preserves line structure verbatim. RfcTextParser strips RFC page furniture and extracts masthead fields, section headings and RFC cross-references.

IWebsiteParser implementations for text/plain responses.

PlainTextParser preserves line structure verbatim. RfcTextParser strips
RFC page furniture and extracts masthead fields, section headings and
RFC cross-references.
raw docstring

plain-text-parserclj

(plain-text-parser)
source

rfc-text-parserclj

(rfc-text-parser)
source

cljdoc builds & hosts documentation for Clojure/Script libraries